# ReportRunMetricsResponseReportRunMetricResult

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**metric_name** | **str** | Output. The name of the metric. | [optional] 
**metric_node_id** | **str** | Output. The ID of the node which reports the metric. | [optional] 
**status** | [**ReportRunMetricsResponseReportRunMetricResultStatus**](ReportRunMetricsResponseReportRunMetricResultStatus.md) |  | [optional] 
**message** | **str** | Output. The detailed message of the error of the reporting. | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


